package com.miaxis.gan.service.impl;

import java.util.*;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.miaxis.common.config.ShiShenConfig;
import com.miaxis.disease.domain.DiseasePart;
import com.miaxis.disease.dto.DiseasePartDto;
import com.miaxis.disease.mapper.DiseasePartMapper;
import com.miaxis.gan.dto.GanZhiDto;
import com.miaxis.gan.vo.GanZhiKongWangVo;
import com.miaxis.gan.vo.GanZhiNaYinVo;
import com.miaxis.gan.vo.GanZhiRowVo;
import com.miaxis.number.domain.NumberYun;
import com.miaxis.number.mapper.NumberYunMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.apache.commons.lang3.StringUtils;
import com.miaxis.gan.mapper.GanZhiMapper;
import com.miaxis.gan.domain.GanZhi;
import com.miaxis.gan.service.IGanZhiService;

/**
 * 天干地支Service业务层处理
 *
 * @author miaxis
 * @date 2023-11-16
 */
@Service
public class GanZhiServiceImpl extends ServiceImpl<GanZhiMapper, GanZhi> implements IGanZhiService {
    @Autowired
    private GanZhiMapper ganZhiMapper;

    @Autowired
    private NumberYunMapper numberYunMapper;

    @Autowired
    private DiseasePartMapper diseasePartMapper;

    @Autowired
    private ShiShenConfig shiShenConfig;

    /**
     * 查询天干地支列表
     *
     * @param ganZhi 天干地支
     * @return 天干地支
     */
    @Override
    public List<GanZhi> selectGanZhiList(GanZhi ganZhi) {
        return ganZhiMapper.selectGanZhiList(ganZhi);
    }

    @Override
    public List<GanZhiRowVo> selectGanZhiRowVoList(GanZhiDto ganZhiDto) {

        List<GanZhiRowVo> list = this.getGanZhiRowVoList(ganZhiDto);
        if (ganZhiDto.getSex() == 1) {
            list.get(4).setShiShen1("元男");
        } else if (ganZhiDto.getSex() == 2) {
            list.get(4).setShiShen1("元女");
        }

        /*-----------------------十神 开始-------------------*/
        for (int i = 0; i < list.size(); i++) {

            if ((i == 0 || i == 2 || i == 6) && i != 4) {

                String zhengYin = shiShenConfig.getZhengYin().get(list.get(i).getName()); //正印
                String shiShen = shiShenConfig.getShiShen().get(list.get(i).getName());  //食神
                String zhengGuan = shiShenConfig.getZhengGuan().get(list.get(i).getName()); //正官
                String zhengCai = shiShenConfig.getZhengCai().get(list.get(i).getName()); //正财
                String qiSha = shiShenConfig.getQiSha().get(list.get(i).getName());  //七杀
                String pianYin = shiShenConfig.getPianYin().get(list.get(i).getName()); //偏印
                String shangGuan = shiShenConfig.getShangGuan().get(list.get(i).getName()); // 伤官
                String jieCai = shiShenConfig.getJieCai().get(list.get(i).getName()); // 劫财
                String biJian = shiShenConfig.getBiJian().get(list.get(i).getName()); // 比肩
                String pianCai = shiShenConfig.getPianCai().get(list.get(i).getName()); // 偏财

                if (list.get(4).getName().equals(zhengYin)) { //比对出正印
                    list.get(i).setShiShen1("正印");
                }
                if (list.get(4).getName().equals(shiShen)) { //比对出食神
                    list.get(i).setShiShen1("食神");
                }
                if (list.get(4).getName().equals(zhengGuan)) { //比对出正官
                    list.get(i).setShiShen1("正官");
                }
                if (list.get(4).getName().equals(zhengCai)) { //比对出正财
                    list.get(i).setShiShen1("正财");
                }
                if (list.get(4).getName().equals(qiSha)) { //比对出七杀
                    list.get(i).setShiShen1("七杀");
                }
                if (list.get(4).getName().equals(pianYin)) { //比对出偏印
                    list.get(i).setShiShen1("偏印");
                }
                if (list.get(4).getName().equals(shangGuan)) { //比对出伤官
                    list.get(i).setShiShen1("伤官");
                }
                if (list.get(4).getName().equals(jieCai)) { //比对出劫财
                    list.get(i).setShiShen1("劫财");
                }
                if (list.get(4).getName().equals(biJian)) { //比对出比肩
                    list.get(i).setShiShen1("比肩");
                }
                if (list.get(4).getName().equals(pianCai)) { //比对出偏财
                    list.get(i).setShiShen1("偏财");
                }

            }

            if ((i == 1 || i == 3 || i == 5 || i == 7) && i != 4) {   //地支

                String benQi = shiShenConfig.getBenQi().get(list.get(i).getName());    //戊
                String zhongQi = shiShenConfig.getZhongQi().get(list.get(i).getName()); //乙
                String yuQi = shiShenConfig.getYuQi().get(list.get(i).getName());   //癸

                /*------------------------正印--------------------------*/
                String zhengYinBenQi = (benQi != null) ? shiShenConfig.getZhengYin().get(benQi) : null; //正印本气
                String zhengYinZhongQi = (zhongQi != null) ? shiShenConfig.getZhengYin().get(zhongQi) : null; //正印中余
                String zhengYinYuQi = (yuQi != null) ? shiShenConfig.getZhengYin().get(yuQi) : null; //正印余气

                if (StringUtils.isNotEmpty(zhengYinBenQi) && list.get(4).getName().equals(zhengYinBenQi)) { //比对出正印
                    list.get(i).setShiShen1(benQi + "(正印)");
                }
                if (StringUtils.isNotEmpty(zhengYinZhongQi) && list.get(4).getName().equals(zhengYinZhongQi)) { //比对出正印
                    list.get(i).setShiShen2(zhongQi + "(正印)");
                }
                if (StringUtils.isNotEmpty(zhengYinYuQi) && list.get(4).getName().equals(zhengYinYuQi)) { //比对出正印
                    list.get(i).setShiShen3(yuQi + "(正印)");
                }


                /*------------------------食神-----------------------------*/
                String shiShenBenQi = (benQi != null) ? shiShenConfig.getShiShen().get(benQi) : null; //食神本气
                String shiShenZhongQi = (zhongQi != null) ? shiShenConfig.getShiShen().get(zhongQi) : null; //食神中气
                String shiShenYuQi = (yuQi != null) ? shiShenConfig.getShiShen().get(yuQi) : null; //食神余气

                if (StringUtils.isNotEmpty(shiShenBenQi) && list.get(4).getName().equals(shiShenBenQi)) { //比对出食神
                    list.get(i).setShiShen1(benQi + "(食神)");
                }
                if (StringUtils.isNotEmpty(shiShenZhongQi) && list.get(4).getName().equals(shiShenZhongQi)) { //比对出食神
                    list.get(i).setShiShen2(zhongQi + "(食神)");
                }
                if (StringUtils.isNotEmpty(shiShenYuQi) && list.get(4).getName().equals(shiShenYuQi)) { //比对出食神
                    list.get(i).setShiShen3(yuQi + "(食神)");
                }

                /*------------------------正官-----------------------------*/
                String zhengGuanBenQi = (benQi != null) ? shiShenConfig.getZhengGuan().get(benQi) : null; //正官本气
                String zhengGuanZhongQi = (zhongQi != null) ? shiShenConfig.getZhengGuan().get(zhongQi) : null; //正官中气
                String zhengGuanYuQi = (yuQi != null) ? shiShenConfig.getZhengGuan().get(yuQi) : null; //正官 余气

                if (StringUtils.isNotEmpty(zhengGuanBenQi) && list.get(4).getName().equals(zhengGuanBenQi)) { //比对出正官
                    list.get(i).setShiShen1(benQi + "(正官)");
                }
                if (StringUtils.isNotEmpty(zhengGuanZhongQi) && list.get(4).getName().equals(zhengGuanZhongQi)) { //比对出正官
                    list.get(i).setShiShen2(zhongQi + "(正官)");
                }
                if (StringUtils.isNotEmpty(zhengGuanYuQi) && list.get(4).getName().equals(zhengGuanYuQi)) { //比对出正官
                    list.get(i).setShiShen3(yuQi + "(正官)");
                }

                /*------------------------正财-----------------------------*/
                String zhengCaiBenQi = (benQi != null) ? shiShenConfig.getZhengCai().get(benQi) : null; //正财本气
                String zhengCaiZhongQi = (zhongQi != null) ? shiShenConfig.getZhengCai().get(zhongQi) : null; //正财中气
                String zhengCaiYuQi = (yuQi != null) ? shiShenConfig.getZhengCai().get(yuQi) : null; //正财余气

                if (StringUtils.isNotEmpty(zhengCaiBenQi) && list.get(4).getName().equals(zhengCaiBenQi)) { //比对出正财
                    list.get(i).setShiShen1(benQi + "(正财)");
                }
                if (StringUtils.isNotEmpty(zhengCaiZhongQi) && list.get(4).getName().equals(zhengCaiZhongQi)) { //比对出正财
                    list.get(i).setShiShen2(zhongQi + "(正财)");
                }
                if (StringUtils.isNotEmpty(zhengCaiYuQi) && list.get(4).getName().equals(zhengCaiYuQi)) { //比对出正财
                    list.get(i).setShiShen3(yuQi + "(正财)");
                }


                /*------------------------七杀-----------------------------*/
                String qiShaBenQi = (benQi != null) ? shiShenConfig.getQiSha().get(benQi) : null; //七杀本气
                String qiShaZhongQi = (zhongQi != null) ? shiShenConfig.getQiSha().get(zhongQi) : null; //七杀中气
                String qiShaYuQi = (yuQi != null) ? shiShenConfig.getQiSha().get(yuQi) : null; //七杀余气

                if (StringUtils.isNotEmpty(qiShaBenQi) && list.get(4).getName().equals(qiShaBenQi)) { //比对出七杀
                    list.get(i).setShiShen1(benQi + "(七杀)");
                }
                if (StringUtils.isNotEmpty(qiShaZhongQi) && list.get(4).getName().equals(qiShaZhongQi)) { //比对出七杀
                    list.get(i).setShiShen2(zhongQi + "(七杀)");
                }
                if (StringUtils.isNotEmpty(qiShaYuQi) && list.get(4).getName().equals(qiShaYuQi)) { //比对出七杀
                    list.get(i).setShiShen3(yuQi + "(七杀)");
                }


                /*------------------------偏印-----------------------------*/
                String pianYinBenQi = (benQi != null) ? shiShenConfig.getPianYin().get(benQi) : null; //偏印本气
                String pianYinZhongQi = (zhongQi != null) ? shiShenConfig.getPianYin().get(zhongQi) : null; //偏印中气
                String pianYinYuQi = (yuQi != null) ? shiShenConfig.getPianYin().get(yuQi) : null; //偏印余气

                if (StringUtils.isNotEmpty(pianYinBenQi) && list.get(4).getName().equals(pianYinBenQi)) { //比对出七杀
                    list.get(i).setShiShen1(benQi + "(偏印)");
                }
                if (StringUtils.isNotEmpty(pianYinZhongQi) && list.get(4).getName().equals(pianYinZhongQi)) { //比对出七杀
                    list.get(i).setShiShen2(zhongQi + "(偏印)");
                }
                if (StringUtils.isNotEmpty(pianYinYuQi) && list.get(4).getName().equals(pianYinYuQi)) { //比对出七杀
                    list.get(i).setShiShen3(yuQi + "(偏印)");
                }

                /*------------------------伤官-----------------------------*/
                String shangGuanBenQi = (benQi != null) ? shiShenConfig.getShangGuan().get(benQi) : null; //伤官本气
                String shangGuanZhongQi = (zhongQi != null) ? shiShenConfig.getShangGuan().get(zhongQi) : null; //伤官中气
                String shangGuanYuQi = (yuQi != null) ? shiShenConfig.getShangGuan().get(yuQi) : null; //伤官余气

                if (StringUtils.isNotEmpty(shangGuanBenQi) && list.get(4).getName().equals(shangGuanBenQi)) { //比对出伤官
                    list.get(i).setShiShen1(benQi + "(伤官)");
                }
                if (StringUtils.isNotEmpty(shangGuanZhongQi) && list.get(4).getName().equals(shangGuanZhongQi)) { //比对出伤官
                    list.get(i).setShiShen2(zhongQi + "(伤官)");
                }
                if (StringUtils.isNotEmpty(shangGuanYuQi) && list.get(4).getName().equals(shangGuanYuQi)) { //比对出伤官
                    list.get(i).setShiShen3(yuQi + "(伤官)");
                }


                /*------------------------劫财-----------------------------*/
                String jieCaiBenQi = (benQi != null) ? shiShenConfig.getJieCai().get(benQi) : null; //劫财本气
                String jieCaiZhongQi = (zhongQi != null) ? shiShenConfig.getJieCai().get(zhongQi) : null; //劫财中气
                String jieCaiYuQi = (yuQi != null) ? shiShenConfig.getJieCai().get(yuQi) : null; //劫财余气

                if (StringUtils.isNotEmpty(jieCaiBenQi) && list.get(4).getName().equals(jieCaiBenQi)) { //比对出劫财
                    list.get(i).setShiShen1(benQi + "(劫财)");
                }
                if (StringUtils.isNotEmpty(jieCaiZhongQi) && list.get(4).getName().equals(jieCaiZhongQi)) { //比对出劫财
                    list.get(i).setShiShen2(zhongQi + "(劫财)");
                }
                if (StringUtils.isNotEmpty(jieCaiYuQi) && list.get(4).getName().equals(jieCaiYuQi)) { //比对出劫财
                    list.get(i).setShiShen3(yuQi + "(劫财)");
                }

                /*------------------------比肩-----------------------------*/
                String biJianBenQi = (benQi != null) ? shiShenConfig.getBiJian().get(benQi) : null; //比肩本气
                String biJianZhongQi = (zhongQi != null) ? shiShenConfig.getBiJian().get(zhongQi) : null; //比肩中气
                String biJianYuQi = (yuQi != null) ? shiShenConfig.getBiJian().get(yuQi) : null; //比肩余气

                if (StringUtils.isNotEmpty(biJianBenQi) && list.get(4).getName().equals(biJianBenQi)) {
                    list.get(i).setShiShen1(benQi + "(比肩)");
                }
                if (StringUtils.isNotEmpty(biJianZhongQi) && list.get(4).getName().equals(biJianZhongQi)) {
                    list.get(i).setShiShen2(zhongQi + "(比肩)");
                }
                if (StringUtils.isNotEmpty(biJianYuQi) && list.get(4).getName().equals(biJianYuQi)) {
                    list.get(i).setShiShen3(yuQi + "(比肩)");
                }

                /*------------------------偏财-----------------------------*/
                String pianCaiBenQi = (benQi != null) ? shiShenConfig.getPianCai().get(benQi) : null; //偏财本气
                String pianCaiZhongQi = (zhongQi != null) ? shiShenConfig.getPianCai().get(zhongQi) : null; //偏财中气
                String pianCaiYuQi = (yuQi != null) ? shiShenConfig.getPianCai().get(yuQi) : null; //偏财余气

                if (StringUtils.isNotEmpty(pianCaiBenQi) && list.get(4).getName().equals(pianCaiBenQi)) { //比对出偏财
                    list.get(i).setShiShen1(benQi + "(偏财)");
                }
                if (StringUtils.isNotEmpty(pianCaiZhongQi) && list.get(4).getName().equals(pianCaiZhongQi)) { //比对出偏财
                    list.get(i).setShiShen2(zhongQi + "(偏财)");
                }
                if (StringUtils.isNotEmpty(pianCaiYuQi) && list.get(4).getName().equals(pianCaiYuQi)) { //比对出偏财
                    list.get(i).setShiShen3(yuQi + "(偏财)");
                }

            }


        }
        /*-----------------------十神 结束-------------------*/

        return list;
    }


    @Override
    public List<GanZhiNaYinVo> selectGanZhiNaYinList(GanZhiDto ganZhiDto) {

        String yearZhuNaYinKey = ganZhiDto.getYearGan() + ganZhiDto.getYearZhi();
        String monthZhuNaYinKey = ganZhiDto.getMonthGan() + ganZhiDto.getMonthZhi();
        String dayZhuNaYinKey = ganZhiDto.getDayGan() + ganZhiDto.getDayZhi();
        String timeZhuNaYinKey = ganZhiDto.getTimeGan() + ganZhiDto.getTimeZhi();

        String yearZhuNaYin = shiShenConfig.getNaYin().get(yearZhuNaYinKey);
        String monthZhuNaYin = shiShenConfig.getNaYin().get(monthZhuNaYinKey);
        String dayZhuNaYin = shiShenConfig.getNaYin().get(dayZhuNaYinKey);
        String timeZhuNaYin = shiShenConfig.getNaYin().get(timeZhuNaYinKey);

        GanZhiNaYinVo yearNaYinVo = new GanZhiNaYinVo();
        yearNaYinVo.setZhu("年");
        yearNaYinVo.setNaYin(yearZhuNaYin);
        GanZhiNaYinVo monthNaYinVo = new GanZhiNaYinVo();
        monthNaYinVo.setZhu("月");
        monthNaYinVo.setNaYin(monthZhuNaYin);
        GanZhiNaYinVo dayNaYinVo = new GanZhiNaYinVo();
        dayNaYinVo.setZhu("日");
        dayNaYinVo.setNaYin(dayZhuNaYin);
        GanZhiNaYinVo timeNaYinVo = new GanZhiNaYinVo();
        timeNaYinVo.setZhu("时");
        timeNaYinVo.setNaYin(timeZhuNaYin);

        List<GanZhiNaYinVo> list = new ArrayList<GanZhiNaYinVo>();
        list.add(yearNaYinVo);
        list.add(monthNaYinVo);
        list.add(dayNaYinVo);
        list.add(timeNaYinVo);
        return list;
    }


    @Override
    public List<GanZhiKongWangVo> selectGanZhiKongWangList(GanZhiDto ganZhiDto) {

        String yearZhuKongWangKey = ganZhiDto.getYearGan() + ganZhiDto.getYearZhi();
        String monthZhuKongWangKey = ganZhiDto.getMonthGan() + ganZhiDto.getMonthZhi();
        String dayZhuNaKongWangKey = ganZhiDto.getDayGan() + ganZhiDto.getDayZhi();
        String timeZhuNaKongWangKey = ganZhiDto.getTimeGan() + ganZhiDto.getTimeZhi();

        String yearZhuKongWang = shiShenConfig.getKongWang().get(yearZhuKongWangKey);
        String monthZhuKongWang = shiShenConfig.getKongWang().get(monthZhuKongWangKey);
        String dayZhuKongWang = shiShenConfig.getKongWang().get(dayZhuNaKongWangKey);
        String timeZhuKongWang = shiShenConfig.getKongWang().get(timeZhuNaKongWangKey);

        GanZhiKongWangVo yearKongWangVo = new GanZhiKongWangVo();
        yearKongWangVo.setZhu("年");
        yearKongWangVo.setKongWang(yearZhuKongWang);
        GanZhiKongWangVo monthKongWangVo = new GanZhiKongWangVo();
        monthKongWangVo.setZhu("月");
        monthKongWangVo.setKongWang(monthZhuKongWang);
        GanZhiKongWangVo dayKongWangVo = new GanZhiKongWangVo();
        dayKongWangVo.setZhu("日");
        dayKongWangVo.setKongWang(dayZhuKongWang);
        GanZhiKongWangVo timeKongWangVo = new GanZhiKongWangVo();
        timeKongWangVo.setZhu("时");
        timeKongWangVo.setKongWang(timeZhuKongWang);

        List<GanZhiKongWangVo> list = new ArrayList<GanZhiKongWangVo>();
        list.add(yearKongWangVo);
        list.add(monthKongWangVo);
        list.add(dayKongWangVo);
        list.add(timeKongWangVo);
        return list;
    }

    @Override
    public Map<String, Object> getRiYuanQr(GanZhiDto ganZhiDto) {
        /*-------------------日元身强身弱---------------------*/
        List<GanZhiRowVo> list = this.getGanZhiRowVoList(ganZhiDto);
        int yearGanQR = ShiShenConfig.generateRelationship(list.get(4).getFive(), list.get(0).getFive());
        int yearZhiQR = ShiShenConfig.generateRelationship(list.get(4).getFive(), list.get(1).getFive());
        int monthGanQR = ShiShenConfig.generateRelationship(list.get(4).getFive(), list.get(2).getFive());
        int monthZhiQR = ShiShenConfig.generateRelationship(list.get(4).getFive(), list.get(3).getFive());
        //     int dayGanQR = ShiShenConfig.generateRelationship(list.get(4).getFive(),list.get(4).getFive());
        int dayZhiQR = ShiShenConfig.generateRelationship(list.get(4).getFive(), list.get(5).getFive());
        int timeGanQR = ShiShenConfig.generateRelationship(list.get(4).getFive(), list.get(6).getFive());
        int timeZhiQR = ShiShenConfig.generateRelationship(list.get(4).getFive(), list.get(7).getFive());

        int score = 0;
        if (yearGanQR > 0) {
            score += 8;
        }
        if (yearZhiQR > 0) {
            score += 4;
        }
        if (monthGanQR > 0) {
            score += 12;
        }
        if (monthZhiQR > 0) {
            score += 40;
        }
        if (dayZhiQR > 0) {
            score += 12;
        }
        if (timeGanQR > 0) {
            score += 12;
        }
        if (timeZhiQR > 0) {
            score += 12;
        }

        List<String> xiYong = null;
        String fiveQr = null;
        if (score > 50) {
            fiveQr = list.get(4).getFive() + "强";
            xiYong = shiShenConfig.getXiYong().get(fiveQr);
        } else {
            fiveQr = list.get(4).getFive() + "弱";
            xiYong = shiShenConfig.getXiYong().get(fiveQr);
        }
        String xi1 = xiYong.get(0);
        String xi2 = xiYong.get(1);

        Map<String, Integer> fiveCountMap = this.getGanZhiRowVoCount(ganZhiDto);
        int xi1Count = fiveCountMap.get(xi1);
        int xi2Count = fiveCountMap.get(xi2);

        if (xi1Count > 3) {
            xiYong.remove(xi1);
        }
        if (xi2Count > 3) {
            xiYong.remove(xi2);
        }

        System.out.println("喜用：" + xiYong);

        Map<String, Object> qr = new TreeMap<String, Object>();
        qr.put("score", score);
        qr.put("qr", fiveQr);
        qr.put("xiYong", xiYong);

        return qr;
    }


    @Override
    public List<DiseasePart> getJiBin(GanZhiDto ganZhiDto) {
        List<GanZhiRowVo> ganZhiRowVoList = this.selectGanZhiRowVoList(ganZhiDto);
        String sex = ganZhiRowVoList.get(4).getShiShen1();

        String gender = null;
        if ("元男".equals(sex)) {  //男性疾病
            sex = "1,3";
        } else if ("元女".equals(sex)) {  //女性疾病
            sex = "2,3";
        }

        List<String> partZ = new ArrayList<String>();
        List<String> partQ = new ArrayList<String>();




        /*--------------------------年柱---------------------------*/
        //天干 头
        String yearGanShiShen = ganZhiRowVoList.get(0).getShiShen1();
        if("七杀".indexOf(yearGanShiShen)>0) { //存在七杀
            partZ.add("头");
        }
        if("偏印".indexOf(yearGanShiShen)>0) { //存在七杀
            partQ.add("头");
        }
        //地支 脖子
        String yearZhiShiShen1 = ganZhiRowVoList.get(1).getShiShen1(); //脖子
        String yearZhiShiShen2 = ganZhiRowVoList.get(1).getShiShen2(); //脖子
        String yearZhiShiShen3 = ganZhiRowVoList.get(1).getShiShen3(); //脖子
        if("七杀".indexOf(yearZhiShiShen1)>0) { //存在七杀
            partZ.add("脖子");
        }
        if("七杀".indexOf(yearZhiShiShen2)>0) { //存在七杀
            partZ.add("脖子");
        }
        if("七杀".indexOf(yearZhiShiShen3)>0) { //存在七杀
            partZ.add("脖子");
        }
        if("偏印".indexOf(yearZhiShiShen1)>0) { //存在偏印
            partQ.add("脖子");
        }
        if("偏印".indexOf(yearZhiShiShen2)>0) { //存在偏印
            partQ.add("脖子");
        }
        if("偏印".indexOf(yearZhiShiShen3)>0) { //存在偏印
            partQ.add("脖子");
        }

        /*--------------------------月柱---------------------------*/

        //天干 胸部
        String monthGanShiShen = ganZhiRowVoList.get(2).getShiShen1();
        if("七杀".indexOf(monthGanShiShen)>0) { //存在七杀
            partZ.add("胸部");
        }
        if("偏印".indexOf(monthGanShiShen)>0) { //存在七杀
            partQ.add("胸部");
        }
        //地支 脖子
        String monthZhiShiShen1 = ganZhiRowVoList.get(3).getShiShen1();
        String monthZhiShiShen2 = ganZhiRowVoList.get(3).getShiShen2();
        String monthZhiShiShen3 = ganZhiRowVoList.get(3).getShiShen3();
        if("七杀".indexOf(monthZhiShiShen1)>0) { //存在七杀
            partZ.add("腹部");
        }
        if("七杀".indexOf(monthZhiShiShen2)>0) { //存在七杀
            partZ.add("腹部");
        }
        if("七杀".indexOf(monthZhiShiShen3)>0) { //存在七杀
            partZ.add("腹部");
        }
        if("偏印".indexOf(monthZhiShiShen1)>0) { //存在偏印
            partQ.add("腹部");
        }
        if("偏印".indexOf(monthZhiShiShen2)>0) { //存在偏印
            partQ.add("腹部");
        }
        if("偏印".indexOf(monthZhiShiShen3)>0) { //存在偏印
            partQ.add("腹部");
        }

        /*--------------------------日柱---------------------------*/
        //天干
        String dayGanShiShen = ganZhiRowVoList.get(4).getShiShen1();
        if("七杀".indexOf(dayGanShiShen)>0) { //存在七杀
            partZ.add("小腹");
        }
        if("偏印".indexOf(dayGanShiShen)>0) { //存在七杀
            partQ.add("小腹");
        }
        //地支 脖子
        String dayZhiShiShen1 = ganZhiRowVoList.get(5).getShiShen1();
        String dayZhiShiShen2 = ganZhiRowVoList.get(5).getShiShen2();
        String dayZhiShiShen3 = ganZhiRowVoList.get(5).getShiShen3();
        if("七杀".indexOf(dayZhiShiShen1)>0) { //存在七杀
            partZ.add("屁股");
        }
        if("七杀".indexOf(dayZhiShiShen2)>0) { //存在七杀
            partZ.add("屁股");
        }
        if("七杀".indexOf(dayZhiShiShen3)>0) { //存在七杀
            partZ.add("屁股");
        }
        if("偏印".indexOf(dayZhiShiShen1)>0) { //存在偏印
            partQ.add("屁股");
        }
        if("偏印".indexOf(dayZhiShiShen2)>0) { //存在偏印
            partQ.add("屁股");
        }
        if("偏印".indexOf(dayZhiShiShen3)>0) { //存在偏印
            partQ.add("屁股");
        }

        /*--------------------------时柱---------------------------*/
        //天干
//        String timeGanShiShen = ganZhiRowVoList.get(6).getShiShen1();
//        if("七杀".indexOf(timeGanShiShen)>0) { //存在七杀
//            partZ.add("小腹");
//        }
//        if("偏印".indexOf(timeGanShiShen)>0) { //存在七杀
//            partQ.add("小腹");
//        }
//        //地支 脖子
//        String timeZhiShiShen1 = ganZhiRowVoList.get(7).getShiShen1();
//        String timeZhiShiShen2 = ganZhiRowVoList.get(7).getShiShen2();
//        String timeZhiShiShen3 = ganZhiRowVoList.get(7).getShiShen3();
//        if("七杀".indexOf(timeZhiShiShen1)>0) { //存在七杀
//            partZ.add("小腿");
//        }
//        if("七杀".indexOf(timeZhiShiShen2)>0) { //存在七杀
//            partZ.add("小腿");
//        }
//        if("七杀".indexOf(timeZhiShiShen3)>0) { //存在七杀
//            partZ.add("小腿");
//        }
//        if("偏印".indexOf(timeZhiShiShen1)>0) { //存在偏印
//            partQ.add("小腿");
//        }
//        if("偏印".indexOf(timeZhiShiShen2)>0) { //存在偏印
//            partQ.add("小腿");
//        }
//        if("偏印".indexOf(timeZhiShiShen3)>0) { //存在偏印
//            partQ.add("小腿");
//        }
//
//        DiseasePartDto diseasePartQDto = new DiseasePartDto();
//        diseasePartQDto.setSex(sex);
//        diseasePartQDto.setDegree("轻症");
//        diseasePartQDto.setParts(partQ);
//
        DiseasePartDto diseasePartZDto = new DiseasePartDto();
        diseasePartZDto.setSex(sex);
        diseasePartZDto.setDegree("严重");
        diseasePartZDto.setParts(partZ);
//
//        List<DiseasePart> diseasePartQList = diseasePartMapper.selectDiseasePartList(diseasePartZDto);
//        List<DiseasePart> diseasePartZList = diseasePartMapper.selectDiseasePartList(diseasePartZDto);
//        diseasePartQList.addAll(diseasePartZList);

        return null;
    }


    @Override
    public Map<String, Object> getNumberYun(Map<String, Object> qr) {

        List<String> numberList = new ArrayList<String>();
        List<String> xiYong = (List<String>) qr.get("xiYong");

        for (int i = 0; i < xiYong.size(); i++) {
            List<String> numList = shiShenConfig.getXiNumber().get(xiYong.get(i));
            numberList.addAll(numList);
        }

        List<NumberYun> numberYunList = numberYunMapper.getNumberYunByIds(numberList);


        //转字符串
        StringJoiner joiner = new StringJoiner(",");
        for (String number : numberList) {
            joiner.add(number);
        }
        String numbers = joiner.toString();


        Map<String, Object> resultMap = new TreeMap<String, Object>();
        resultMap.put("numberYuns", numbers);
        resultMap.put("numberYunList", numberYunList);

        return resultMap;
    }


    /**
     * 干支组装
     *
     * @param ganZhiDto
     * @return
     */
    private List<GanZhiRowVo> getGanZhiRowVoList(GanZhiDto ganZhiDto) {

        String yearGanFive = shiShenConfig.getGanZhiFive().get(ganZhiDto.getYearGan());
        String yearZhiFive = shiShenConfig.getGanZhiFive().get(ganZhiDto.getYearZhi());
        String monthGanFive = shiShenConfig.getGanZhiFive().get(ganZhiDto.getMonthGan());
        String monthZhiFive = shiShenConfig.getGanZhiFive().get(ganZhiDto.getMonthZhi());
        String dayGanFive = shiShenConfig.getGanZhiFive().get(ganZhiDto.getDayGan());
        String dayZhiFive = shiShenConfig.getGanZhiFive().get(ganZhiDto.getDayZhi());
        String timeGanFive = shiShenConfig.getGanZhiFive().get(ganZhiDto.getTimeGan());
        String timeZhiFive = shiShenConfig.getGanZhiFive().get(ganZhiDto.getTimeZhi());


        String yearGanColor = shiShenConfig.getGanZhiColor().get(ganZhiDto.getYearGan());
        String yearZhiColor = shiShenConfig.getGanZhiColor().get(ganZhiDto.getYearZhi());
        String monthGanColor = shiShenConfig.getGanZhiColor().get(ganZhiDto.getMonthGan());
        String monthZhiColor = shiShenConfig.getGanZhiColor().get(ganZhiDto.getMonthZhi());
        String dayGanColor = shiShenConfig.getGanZhiColor().get(ganZhiDto.getDayGan());
        String dayZhiColor = shiShenConfig.getGanZhiColor().get(ganZhiDto.getDayZhi());
        String timeGanColor = shiShenConfig.getGanZhiColor().get(ganZhiDto.getTimeGan());
        String timeZhiColor = shiShenConfig.getGanZhiColor().get(ganZhiDto.getTimeZhi());

        GanZhiRowVo yearGan = new GanZhiRowVo();
        yearGan.setGongWei("年干");
        yearGan.setFive(yearGanFive);
        yearGan.setColor(yearGanColor);
        yearGan.setName(ganZhiDto.getYearGan());

        GanZhiRowVo yearZhi = new GanZhiRowVo();
        yearZhi.setGongWei("年支");
        yearZhi.setFive(yearZhiFive);
        yearZhi.setColor(yearZhiColor);
        yearZhi.setName(ganZhiDto.getYearZhi());

        GanZhiRowVo monthGan = new GanZhiRowVo();
        monthGan.setGongWei("月干");
        monthGan.setFive(monthGanFive);
        monthGan.setColor(monthGanColor);
        monthGan.setName(ganZhiDto.getMonthGan());


        GanZhiRowVo monthZhi = new GanZhiRowVo();
        monthZhi.setGongWei("月支");
        monthZhi.setFive(monthZhiFive);
        monthZhi.setColor(monthZhiColor);
        monthZhi.setName(ganZhiDto.getMonthZhi());

        GanZhiRowVo dayGan = new GanZhiRowVo();
        dayGan.setGongWei("日干");
        dayGan.setFive(dayGanFive);
        dayGan.setColor(dayGanColor);
        dayGan.setName(ganZhiDto.getDayGan());


        GanZhiRowVo dayZhi = new GanZhiRowVo();
        dayZhi.setGongWei("日支");
        dayZhi.setFive(dayZhiFive);
        dayZhi.setColor(dayZhiColor);
        dayZhi.setName(ganZhiDto.getDayZhi());

        GanZhiRowVo timeGan = new GanZhiRowVo();
        timeGan.setGongWei("时干");
        timeGan.setFive(timeGanFive);
        timeGan.setColor(timeGanColor);
        timeGan.setName(ganZhiDto.getTimeGan());

        GanZhiRowVo timeZhi = new GanZhiRowVo();
        timeZhi.setGongWei("时支");
        timeZhi.setFive(timeZhiFive);
        timeZhi.setColor(timeZhiColor);
        timeZhi.setName(ganZhiDto.getDayZhi());

        List<GanZhiRowVo> list = new ArrayList<GanZhiRowVo>();
        list.add(yearGan);
        list.add(yearZhi);
        list.add(monthGan);
        list.add(monthZhi);
        list.add(dayGan);
        list.add(dayZhi);
        list.add(timeGan);
        list.add(timeZhi);

        return list;
    }

    /**
     * 获取五行数量
     *
     * @param ganZhiDto
     * @return
     */
    @Override
    public Map<String, Integer> getGanZhiRowVoCount(GanZhiDto ganZhiDto) {

        Map<String, Integer> fiveCount = new TreeMap<String, Integer>();
        fiveCount.put("木", 0);
        fiveCount.put("火", 0);
        fiveCount.put("土", 0);
        fiveCount.put("金", 0);
        fiveCount.put("水", 0);

        List<GanZhiRowVo> list = this.getGanZhiRowVoList(ganZhiDto);
        for (int i = 0; i < list.size(); i++) {
            String five = list.get(i).getFive();
            Integer fiveC = fiveCount.get(five) + 1;
            fiveCount.put(five, fiveC);
        }
        return fiveCount;
    }


    /**
     * 潮湿平衡
     *
     * @param ganZhiDto
     * @return
     */
    @Override
    public Map<String, Object> getZaoShiCount(GanZhiDto ganZhiDto) {
        List<GanZhiRowVo> list = this.getGanZhiRowVoList(ganZhiDto);

        Map<String, Integer> fiveCount = this.getGanZhiRowVoCount(ganZhiDto);
        int huoCount = fiveCount.get("火");
        int shuiCount = fiveCount.get("水");

        for (int i = 1; i < list.size(); i += 2) {
            String five = list.get(i).getFive();
            if ("土".equals(five)) {
                if (huoCount > shuiCount) {
                    String name = list.get(i).getName();
                    if("戌".equals(name) || "未".equals(name)) {
                        Integer fiveC = fiveCount.get("火") + 1;
                        fiveCount.put("火", fiveC);
                    }
                } else if (huoCount < shuiCount) {
                    String name = list.get(i).getName();
                    if("辰".equals(name) || "丑".equals(name)) {
                        Integer fiveC = fiveCount.get("水") + 1;
                        fiveCount.put("水", fiveC);
                    }
                }
            }
        }
        fiveCount.remove("土");
        fiveCount.remove("金");
        fiveCount.remove("木");


        int huoCount2 = fiveCount.get("火");
        int shuiCoun2 = fiveCount.get("水");

        Map<String,Object> zaoShiMap = new TreeMap<String,Object>();
        zaoShiMap.putAll(fiveCount);


        if(huoCount2-shuiCoun2>=2) {  //火过旺
            zaoShiMap.put("jieshi","过于干燥，火特别多，性情比较暴躁，容易上火，内心上火容易产生无名火，容易被“点燃”生气，身体也容易上火。");
        }  else if (huoCount2-shuiCoun2==1) { //火轻微过旺
            zaoShiMap.put("jieshi","偏干燥，火特别多，性情相对比较急躁。");
        }  else if (huoCount2-shuiCoun2<=-2) {
            zaoShiMap.put("jieshi","过于湿润，大便不成形，湿气太重了，比较会容易肚子，手脚冰凉，气血不活。");
        } else if (huoCount2-shuiCoun2==-1) {
            zaoShiMap.put("jieshi","偏湿润，大便不成形，湿气较重，气血不活。");
        } else if (huoCount2-shuiCoun2==0){
            zaoShiMap.put("jieshi","各个宫位，燥湿达到平衡。不会过湿，过燥。");
        }

        return zaoShiMap;
    }


}